summaryrefslogtreecommitdiffstats
path: root/arts/gui/kde/kartswidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'arts/gui/kde/kartswidget.h')
-rw-r--r--arts/gui/kde/kartswidget.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/arts/gui/kde/kartswidget.h b/arts/gui/kde/kartswidget.h
index 2cd072bc..7e745bf6 100644
--- a/arts/gui/kde/kartswidget.h
+++ b/arts/gui/kde/kartswidget.h
@@ -31,17 +31,17 @@ class KArtsWidgetPrivate;
/**
* KArtsWidget provides a simple way to treat Arts::Widget classes like
- * native Qt widgets. Suppose you use Qt, and want to put an Arts::Widget
- * type into a layout, you can do so using this code
+ * native TQt widgets. Suppose you use TQt, and want to put an Arts::Widget
+ * type into a tqlayout, you can do so using this code
*
* <pre>
* Arts::Widget widget = ...get widget from somewhere...;
* KArtsWidget *w = new KArtsWidget(widget, this);
- * layout->addWidget(w);
+ * tqlayout->addWidget(w);
* </pre>
*
* In line 2 of the code, the "this" is the parent widget (which is usually
* this in Qt code).
*
* The KArtsWidget class keeps a reference to the content widget, so the
* content widget will not be freed until the KArtsWidget gets destroyed.
@@ -57,12 +57,12 @@ public:
/**
* creates a new KArtsWidget
*/
- KArtsWidget( TQWidget* parent, const char* name );
+ KArtsWidget( TQWidget* tqparent, const char* name );
/**
* creates a new KArtsWidget and sets the content to an Arts::Widget
*/
- KArtsWidget( Arts::Widget content, TQWidget* parent, const char* name );
+ KArtsWidget( Arts::Widget content, TQWidget* tqparent, const char* name );
/**
* creates a new KArtsWidget with WidgetFlags and content
@@ -31,17 +31,17 @@ class KArtsWidgetPrivate;
* </pre>
*
- * In line 2 of the code, the "this" is the parent widget (which is usually
- * this in Qt code).
+ * In line 2 of the code, the "this" is the tqparent widget (which is usually
+ * this in TQt code).
*
* The KArtsWidget class keeps a reference to the content widget, so the